import QtQuick 2.4
import Ubuntu.Components 1.3
import Qt.labs.settings 1.0
import QtSystemInfo 5.0
import QtQuick.Window 2.2

Window {
    id: root_window

    property bool isFullscreen: true
    property bool isLandscape: main_view.width > main_view.height
    property bool is24format: true
    property string time_24: "00:00"
    property string time_12: "00:00:ap"
    property string this_day: Qt.formatDateTime(new Date(), "dddd")
    property string this_date: Qt.formatDateTime(new Date(), "d MMMM yyyy")
    property color back_color: "#000"
    property color text_color: UbuntuColors.red

    function updateTime()
    {
        time_24 = Qt.formatDateTime(new Date(), "hh:mm")
        time_12 = Qt.formatDateTime(new Date(), "hh:mm:ap")
        this_day = Qt.formatDateTime(new Date(), "dddd")
        this_date = Qt.formatDateTime(new Date(), "d MMMM yyyy")
    }

    width: units.gu(40)
    height: units.gu(100)
    visibility: isFullscreen ? Window.FullScreen : Window.AutomaticVisibility

    ScreenSaver {
        screenSaverEnabled: !Qt.application.active
    }

    MainView {
        id: main_view

        // Note! applicationName needs to match the "name" field of the click manifest
        applicationName: "nightclock.mivoligo"

        backgroundColor: "#eee"

        anchors.fill: parent

        Settings {
            property alias background_colour: root_window.back_color
            property alias foreground_colour: root_window.text_color
            property alias is_fullscreen: root_window.isFullscreen
            property alias is_24_format: root_window.is24format
        }

        Connections {
            target: Qt.application
            onStateChanged:
                if(Qt.application.state == Qt.ApplicationActive) {
//                    console.log("app is active")
                    perpetuum_timer.interval = 60000 - new Date().getTime() % 60000
                    perpetuum_timer.restart()
                    updateTime()
                }
        }

        Timer {
            id: perpetuum_timer

            interval: 60000 - new Date().getTime() % 60000
            repeat: true
            onTriggered: {
                interval = 60000 - new Date().getTime() % 60000
                restart()
                updateTime()
                console.log("timer trigered, interval = " + perpetuum_timer.interval)
            }
        }

        PageStack {
            id: page_stack
        }

        Component.onCompleted: {
            time_24 = Qt.formatDateTime(new Date(), "hh:mm")
            time_12 = Qt.formatDateTime(new Date(), "hh:mm:ap")
            page_stack.push(Qt.resolvedUrl("qml/Display.qml"))
        }

    }
}

