import QtQuick 2.4
import Ubuntu.Components 1.3
import QtQuick.Layouts 1.1

Page {
    id: root_about


    title: i18n.tr("Informations")

    head {
        sections {
            model: [i18n.tr("Summary"), i18n.tr("Credits"), i18n.tr("Support")]
        }
    }

    Flickable {
        id: page_flickable

        anchors.fill: parent

        contentHeight:  main_column.height + units.gu(2)
        clip: true

        Column {
            id: main_column

            anchors {
                left: parent.left
                right: parent.right
                top: parent.top
            }
            Item {
                id: icon

                visible: root_about.head.sections.selectedIndex === 0
                width: parent.width
                height: app_icon.height + units.gu(1)

                UbuntuShape {
                    id: app_icon

                    width: Math.min(root_about.width/3, 256)
                    height: width
                    anchors.centerIn: parent

                    source: Image {
                        id: icon_image
                        source: "../NightClock.png"
                    }
                    radius: "medium"
                }
            }

            Label {
                id: name

                visible: root_about.head.sections.selectedIndex === 0
                text: "Night Clock\nv0.1.1"
                anchors.horizontalCenter: parent.horizontalCenter
                fontSize: "large"
                horizontalAlignment:  Text.AlignHCenter
            }

            Label {
                id: description_text

                visible: root_about.head.sections.selectedIndex === 0
                width: parent.width
                text: i18n.tr("use it in the daytime too")
                anchors.horizontalCenter: parent.horizontalCenter
                wrapMode: Text.WordWrap
                horizontalAlignment:  Text.AlignHCenter
            }

            ListItem {
                visible: root_about.head.sections.selectedIndex === 0
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

                    Label {
                        Layout.fillWidth: true
                        anchors.verticalCenter: parent.verticalCenter
                        text: i18n.tr("Website")
                        elide: Text.ElideRight
                    }

                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        text: "<a href='https://launchpad.net/night-clock'>launchpad.net/night-clock</a>"
                        onLinkActivated: Qt.openUrlExternally(link)
                    }
                }
            }

            ListItem {
                visible: root_about.head.sections.selectedIndex === 0
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }
                    Label {
                        Layout.fillWidth: true
                        anchors.verticalCenter: parent.verticalCenter
                        text: i18n.tr("License")
                        elide: Text.ElideRight
                    }
                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        text: "<a href='http://opensource.org/licenses/bsd-license.php'>Simplified BSD License</a>"
                        onLinkActivated: Qt.openUrlExternally(link)
                    }
                }
            }

            ListItem {
                visible: root_about.head.sections.selectedIndex === 1
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

                    Label {
                        Layout.fillWidth: true
                        anchors.verticalCenter: parent.verticalCenter
                        text: i18n.tr("Author")
                        elide: Text.ElideRight
                    }

                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        text: "<a href='http://mivoligo.com'>Michał Prędotka</a>"
                        onLinkActivated: Qt.openUrlExternally(link)
                    }
                }
            }



//            ListItem {
//                visible: root_about.head.sections.selectedIndex === 1
//                RowLayout {
//                    spacing: units.gu(2)
//                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

//                    Label {
//                        anchors.verticalCenter: parent.verticalCenter
//                        Layout.fillWidth: true
//                        text: i18n.tr("Testing")
//                        elide: Text.ElideRight
//                    }

//                    Label {
//                        anchors.verticalCenter: parent.verticalCenter
//                        text: "<a href='https://plus.google.com/u/0/+cmtarudy/about'>cm-t arudy</a>"
//                        onLinkActivated: Qt.openUrlExternally(link)
//                    }
//                }
//            }


            ListItem {
                visible: root_about.head.sections.selectedIndex === 2
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        Layout.fillWidth: true
                        text: i18n.tr("Report bugs")
                        elide: Text.ElideRight
                    }

                    Icon {
                        name: "go-next"
                        anchors.verticalCenter: parent.verticalCenter
                        height: parent.height/3
                        width: height
                    }
                }
                onClicked: Qt.openUrlExternally('https://bugs.launchpad.net/night-clock')
            }

            ListItem {
                visible: root_about.head.sections.selectedIndex === 2
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        Layout.fillWidth: true
                        text: i18n.tr("Help with translation")
                        elide: Text.ElideRight
                    }

                    Icon {
                        name: "go-next"
                        anchors.verticalCenter: parent.verticalCenter
                        height: parent.height/3
                        width: height
                    }
                }
                onClicked: Qt.openUrlExternally('https://translations.launchpad.net/night-clock')
            }

            ListItem {
                visible: root_about.head.sections.selectedIndex === 2
                RowLayout {
                    spacing: units.gu(2)
                    anchors { fill: parent; leftMargin: units.gu(2); rightMargin: units.gu(2) }

                    Label {
                        anchors.verticalCenter: parent.verticalCenter
                        Layout.fillWidth: true
                        text: i18n.tr("My other apps")
                        elide: Text.ElideRight
                    }

                    Icon {
                        name: "go-next"
                        anchors.verticalCenter: parent.verticalCenter
                        height: parent.height/3
                        width: height
                    }
                }
                onClicked: Qt.openUrlExternally('scope://com.canonical.scopes.clickstore?q=mivoligo')
            }
        }
    }
}
