import QtQuick 2.4
import Ubuntu.Components 1.3
import QtQuick.Layouts 1.1

Page {
    id: root_settingpage

    title: i18n.tr("Settings")

    Flow {
        id: main_flow
        width: parent.width

        spacing: 0

        Rectangle {
            id: preview_rect

            color: back_color
            width: isLandscape ? root_settingpage.width/2 : root_settingpage.width
            height: isLandscape ? root_settingpage.height : root_settingpage.height/2

            Row {
                id: time_row

                width: parent.width
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                    topMargin: units.gu(2)
                }

                Icon {
                    id: time_h

                    source: is24format ? "../img/" + time_24.charAt(0) + ".svg" : "../img/" + time_12.charAt(0) + ".svg"
                    width: parent.width*4/17
                    height: width * 3/2
                    color: text_color
                }

                Icon {
                    id: time_hh

                    source: is24format ? "../img/" + time_24.charAt(1) + ".svg" : "../img/" + time_12.charAt(1) + ".svg"
                    width: parent.width*4/17
                    height: width * 3/2
                    color: text_color
                }

                Icon {
                    id: time_colon

                    source: "../img/colon.svg"
                    width: parent.width*1/17
                    height: time_h.height
                    color: text_color
                }

                Icon {
                    id: time_m

                    source: is24format ? "../img/" + time_24.charAt(3) + ".svg" : "../img/" + time_12.charAt(3) +".svg"
                    width: parent.width*4/17
                    height: width * 3/2
                    color: text_color
                }

                Icon {
                    id: time_mm

                    source: is24format ? "../img/" + time_24.charAt(4) + ".svg" : "../img/" + time_12.charAt(4) +".svg"
                    width: parent.width*4/17
                    height: width * 3/2
                    color: text_color
                }
            }

            Icon {
                id: time_ap

                visible: !is24format
                source: "../img/" + time_12.charAt(6) +"m.svg"
                anchors {
                    top: time_row.bottom
                    right: time_row.right
                }
                height: time_h.height/4
                width: height
                color: text_color
            }
        }

        Item {
            id: settings_item

            width: preview_rect.width
            height: preview_rect.height

            Column {
                id: settings_column

                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    leftMargin: units.gu(2)
                    rightMargin: units.gu(2)
                }

                ListItem {
                    id: time_format_setting_item

                    RowLayout {
                        anchors.fill: parent

                        Label {
                            text: i18n.tr("24-hour time format")
                            anchors.verticalCenter: parent.verticalCenter
                            Layout.fillWidth: true
                        }

                        Switch {
                            anchors.verticalCenter: parent.verticalCenter
                            checked: is24format
                            onCheckedChanged: is24format = checked
                        }
                    }
                }

                ListItem {
                    id: show_fullscreen_setting_item

                    RowLayout {
                        anchors.fill: parent

                        Label {
                            text: i18n.tr("Fullscreen")
                            anchors.verticalCenter: parent.verticalCenter
                            Layout.fillWidth: true
                        }

                        Switch {
                            anchors.verticalCenter: parent.verticalCenter
                            checked: isFullscreen
                            onCheckedChanged: isFullscreen = checked
                        }
                    }
                }

                ListItem {
                    id: text_color_setting_item

                    Column {
                        spacing: 4

                        Label {
                            text: i18n.tr("Text colour")
                        }

                        Row {
                            Repeater {
                                id: text_color_rep

                                model: [
                                    "#ffffff", "#929292", "#000000",
                                    "#f32c36", "#00a132", "#12a3d8"
                                ]

                                Rectangle {
                                    id: text_color_rect

                                    color: modelData
                                    width: settings_column.width/6
                                    height: units.gu(3)

                                    MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                            text_color = text_color_rect.color

                                        }
                                    }
                                }
                            }
                        }
                    }
                }

                ListItem {
                    id: background_color_setting_item

                    Column {
                        spacing: 4

                        Label {
                            text: i18n.tr("Background colour")
                        }

                        Row {
                            Repeater {
                                id: back_color_rep

                                model: [
                                    "#ffffff", "#929292", "#000000",
                                    "#f32c36", "#00a132", "#12a3d8"
                                ]

                                Rectangle {
                                    id: back_color_rect

                                    color: modelData
                                    width: settings_column.width/6
                                    height: units.gu(3)

                                    MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                            back_color = back_color_rect.color
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
